# RoboOJ — Robot Policy Online Judge

[![Python 3.10+](https://img.shields.io/badge/python-3.10+-blue.svg)](https://www.python.org/downloads/)
[![License: Apache-2.0](https://img.shields.io/badge/License-Apache%202.0-green.svg)](LICENSE)

**RoboOJ** (Robot Policy Online Judge) is a simulation-based evaluation platform for robot learning policies.

> This package is currently under active development. Full functionality will be available in a future release.

## License

[Apache-2.0](LICENSE)
